aboutsummaryrefslogtreecommitdiffstats
path: root/apps/theming/lib
diff options
context:
space:
mode:
authorSimon L. <szaimen@e.mail.de>2025-02-27 12:06:42 +0100
committerSimon L. <szaimen@e.mail.de>2025-02-28 15:32:43 +0100
commit6235ed6222401ef79da7a523fab6f74969b824b8 (patch)
treedec7260ebf0b9d3311e4dc220056eb03396c1be9 /apps/theming/lib
parent951a35cc3841e33e11266ae11dd1eac70c3ab3b3 (diff)
downloadnextcloud-server-6235ed6222401ef79da7a523fab6f74969b824b8.tar.gz
nextcloud-server-6235ed6222401ef79da7a523fab6f74969b824b8.zip
feat(PWA): add `display_override` to set the display-mode to `minimal-ui` on supported browsersenh/49868/add-display-override
Signed-off-by: Simon L. <szaimen@e.mail.de>
Diffstat (limited to 'apps/theming/lib')
-rw-r--r--apps/theming/lib/Controller/ThemingController.php3
1 files changed, 2 insertions, 1 deletions
diff --git a/apps/theming/lib/Controller/ThemingController.php b/apps/theming/lib/Controller/ThemingController.php
index c3f365a11b6..8d9e7aaf060 100644
--- a/apps/theming/lib/Controller/ThemingController.php
+++ b/apps/theming/lib/Controller/ThemingController.php
@@ -422,7 +422,7 @@ class ThemingController extends Controller {
*
* @param string $app ID of the app
* @psalm-suppress LessSpecificReturnStatement The content of the Manifest doesn't need to be described in the return type
* @return JSONResponse<Http::STATUS_OK, array{name: string, short_name: string, start_url: string, theme_color: string, background_color: string, description: string, icons: list<array{src: non-empty-string, type: string, sizes: string}>, display: string}, array{}>|JSONResponse<Http::STATUS_NOT_FOUND, array{}, array{}>
*
* 200: Manifest returned
* 404: App not found
@@ -481,6 +481,7 @@ class ThemingController extends Controller {
'sizes' => '16x16'
]
],
+ 'display_override' => [$this->config->getSystemValueBool('theming.standalone_window.enabled', true) ? 'minimal-ui' : ''],
'display' => $this->config->getSystemValueBool('theming.standalone_window.enabled', true) ? 'standalone' : 'browser'
];
$response = new JSONResponse($responseJS);
@@ -422,7 +422,7 @@ class ThemingController extends Controller {
* @param string $app ID of the app
* @psalm-suppress LessSpecificReturnStatement The content of the Manifest doesn't need to be described in the return type
- * @return JSONResponse<Http::STATUS_OK, array{name: string, short_name: string, start_url: string, theme_color: string, background_color: string, description: string, icons: list<array{src: non-empty-string, type: string, sizes: string}>, display: string}, array{}>|JSONResponse<Http::STATUS_NOT_FOUND, array{}, array{}>
+ * @return JSONResponse<Http::STATUS_OK, array{name: string, short_name: string, start_url: string, theme_color: string, background_color: string, description: string, icons: list<array{src: non-empty-string, type: string, sizes: string}>, display_override: list<string>, display: string}, array{}>|JSONResponse<Http::STATUS_NOT_FOUND, array{}, array{}>
*
* 200: Manifest returned